import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';

class DropdownButtonTile<T> extends StatelessWidget {
  final String subtitle;
  final Widget leading;
  final String title;
  final bool enabled;
  final TextStyle titleTextStyle;
  final TextStyle subtitleTextStyle;
  final T dropdownValue;
  final ValueChanged<T> onDropdownValueChanged;
  final List<DropdownMenuItem<T>> dropdownItems;

  const DropdownButtonTile({
    Key key,
    this.subtitle,
    this.leading,
    this.titleTextStyle,
    this.subtitleTextStyle,
    this.enabled = true,
    this.dropdownValue,
    @required this.dropdownItems,
    this.title,
    this.onDropdownValueChanged,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return tile();
  }

  Widget tile() {
    return ListTile(
      title: Text(title, style: titleTextStyle),
      trailing: DropdownButton<T>(
          value: dropdownValue,
          onChanged: onDropdownValueChanged,
          items: dropdownItems),
      subtitle:
          subtitle != null ? Text(subtitle, style: subtitleTextStyle) : null,
      leading: leading,
      enabled: enabled,
    );
  }
}
