import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter/widgets.dart';

class TextFieldTile extends StatelessWidget {
  final String subtitle;
  final Widget leading;
  final String title;
  final String labelText;
  final bool enabled;
  final TextStyle titleTextStyle;
  final TextStyle subtitleTextStyle;
  final String value;
  final String initialValue;
  final ValueChanged<String> onChanged;
  final List<TextInputFormatter> inputFormatters;

  const TextFieldTile({
    Key key,
    this.subtitle,
    this.leading,
    this.titleTextStyle,
    this.subtitleTextStyle,
    this.enabled = true,
    this.title,
    this.value,
    this.labelText,
    this.initialValue,
    this.onChanged,
    this.inputFormatters,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return tile();
  }

  Widget tile() {
    return ListTile(
      title: Text(title, style: titleTextStyle),
      trailing: SizedBox(
        width: 200,
        child: TextFormField(
            initialValue: initialValue,
            decoration: InputDecoration(
              border: OutlineInputBorder(),
              labelText: labelText ?? "",
            ),
            onChanged: onChanged,
            inputFormatters: inputFormatters),
      ),
      subtitle:
          subtitle != null ? Text(subtitle, style: subtitleTextStyle) : null,
      leading: leading,
      enabled: enabled,
    );
  }

  @override
  void debugFillProperties(DiagnosticPropertiesBuilder properties) {
    super.debugFillProperties(properties);
    properties.add(IterableProperty<TextInputFormatter>(
        'inputFormatters', inputFormatters));
  }
}
